@@ -14,6 +14,7 @@
 
 #include "PerfSocket.hpp"
 #include "Thread.hpp"
+#include <vector>
 
 /* ------------------------------------------------------------------- */
 class Listener : public PerfSocket, public Thread
@@ -27,10 +28,20 @@ public:
     
   // accepts connections and starts Servers
   virtual void Run( void );
+  
+  // Starts the Servers as a daemon 
+  virtual void runAsDaemon(const char *, int);
+
+
+  struct sockaddr_in get_next_UDP();
+  // Checks if the client has already joined, used
+  // only for multicast
+  bool present(struct sockaddr_in);
+
+
 
 protected:
   char *mLocalhost;
-
 }; // end class Listener
 
 #endif // LISTENER_H
