@@ -1,17 +1,18 @@
 /* -------------------------------------------------------------------
  * Server.cpp
- * by Mark Gates <mgates@nlanr.net>
+ * by Mark Gates <mgates@nlanr.net>, Ajay Tirumala (tirumala@ncsa.uiuc.edu>.
  * Copyright 1999, Board of Trustees of the University of Illinois.
  * $Id: Server.cpp,v 1.2 1999/11/03 22:28:01 mgates Exp $
  * -------------------------------------------------------------------
  * A server thread is initiated for each connection accept() returns.
  * Handles sending and receiving data, and then closes socket.
+ * Changes to this version : The server can be run as a daemon
  * ------------------------------------------------------------------- */
 #define HEADERS()
 
 #include "Server.hpp"
 #include "Listener.hpp"
-
+#include "Settings.hpp"
 /* -------------------------------------------------------------------
  * Stores connected socket and socket info.
  * ------------------------------------------------------------------- */
@@ -44,3 +45,4 @@ void Server::Run( void )
     Recv_TCP();
   }
 }
+
