@@ -23,9 +23,9 @@
 #include "Listener.hpp"
 #include "Locale.hpp"
 #include "Condition.hpp"
-
 #include "util.h"
 
+
 /* -------------------------------------------------------------------
  * prototypes
  * ------------------------------------------------------------------- */
@@ -60,7 +60,7 @@ int main( int argc, char **argv )
   // these are usually remapped later by the client or server
   my_signal( SIGTERM, sig_exit );
   my_signal( SIGINT,  sig_exit );
-
+  signal(SIGPIPE,SIG_IGN);
 #ifdef WIN32
   WSADATA wsaData;
   int rc = WSAStartup( 0x202, &wsaData );
@@ -83,6 +83,13 @@ int main( int argc, char **argv )
     theListener = new Listener( gSettings->GetPort(),
                                 gSettings->GetProtocolMode() == kMode_UDP,
                                 gSettings->GetLocalhost() );
+                                
+    
+    // Start the server as a daemon
+    if (gSettings->GetDaemonMode() == true) {
+    	theListener->runAsDaemon(argv[0],LOG_DAEMON);
+    }
+    
     theListener->Start();
     theListener->SetDaemon();
 
@@ -119,7 +126,6 @@ int main( int argc, char **argv )
   Thread::Joinall();
   DELETE_PTR( gSettings );
   DELETE_PTR( theListener );
-
   // all done!
   return 0;
 } // end main
@@ -195,3 +201,7 @@ void cleanup( void )
   WSACleanup();
 #endif
 } // end cleanup
+
+
+
+
